Tutorials — CubicWeb 3.10.1

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.10.1 »

# Tutorials

We present two tutorials of different levels. The blog building tutorial introduces one smoothly to the basic concepts.

Then there is a photo gallery construction tutorial which highlights more advanced concepts such as unit tests, security settings, migration scripts.

- 1. Building a simple blog
- 2. Building a photo gallery with CubicWeb
- 3. Use Windmill with CubicWeb

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.10.1 »